GLmix(x, v = 300, sigma = 1, hist = FALSE, histm = 300, weights = NULL, ...)histm
bins when scalar.sigma is heterogeneous and hist = TRUE the
procedure tries to do separate histogram binning for distinct values of
sigma, however this is only feasible when there are only a small
number of distinct sigma. By default the grid for the binning is
equally spaced on the support of the data. This function does the normal
convolution problem, for gamma mixtures of variances see GVmix, or
for mixtures of both means and variances TLVmix.The predict method for GLmix objects will compute means, medians or
modes of the posterior according to whether the Loss argument is 2, 1
or 0.
Jiang, Wenhua and Cun-Hui Zhang General maximum likelihood empirical Bayes estimation of normal means Ann. Statist., Volume 37, Number 4 (2009), 1647-1684.
Koenker, R and I. Mizera, (2013) ``Convex Optimization, Shape Constraints, Compound Decisions, and Empirical Bayes Rules,'' JASA, 109, 674--685.