Learn R Programming

REBayes (version 0.63)

Gammamix: NPMLE for Gamma Mixtures

Description

A Kiefer-Wolfowitz MLE for Gamma mixture models

Usage

Gammamix(x, v = 300, shape = 1, weights = NULL, ...)

Arguments

x
vector of observed variances
v
A vector of bin boundaries, if scalar then v equally spaced bins are constructed
shape
vector of shape parameters corresponding to x
weights
replicate weights for x obervations, should sum to 1
...
optional parameters passed to KWDual to control optimization

Value

An object of class density with components:

References

Gu J. and R. Koenker (2014) Unobserved heterogeneity in income dynamics: an empirical Bayes perspective, JBES, forthcoming.

See Also

Gammamix for a general implementation for Gamma mixtures