Learn R Programming

REBayes (version 0.63)

Gompertzmix: NPMLE for Gompertz Mixtures

Description

Kiefer-Wolfowitz NPMLE for Gompertz Mixtures of scale parameter

Usage

Gompertzmix(x, v = 300, u = 300, alpha, theta, hist = FALSE, weights = NULL, ...)

Arguments

x
Survival times
v
Grid values for mixing distribution
u
Grid values for mixing distribution
alpha
Shape parameter for Gompertz distribution
theta
Scale parameter for Gompertz Distribution
hist
If TRUE aggregate to histogram counts
weights
replicate weights for x obervations, should sum to 1
...
optional parameters passed to KWDual to control optimization

Value

An object of class density with components

Details

Kiefer Wolfowitz NPMLE density estimation for Gompertz scale mixtures. The histogram option is intended for relatively large problems, say n > 1000, where reducing the sample size dimension is desirable. By default the grid for the binning is equally spaced on the support of the data. Parameterization: f(t|alpha,theta,v) = theta * exp(v) * exp(alpha * t) * exp(-(theta/alpha) * exp(v) * (exp(alpha*t)-1))

References

Kiefer, J. and J. Wolfowitz Consistency of the Maximum Likelihood Estimator in the Presence of Infinitely Many Incidental Parameters Ann. Math. Statist. Volume 27, Number 4 (1956), 887-906.

See Also

Weibullmix