HodgesLehmann: Hodges-Lehmann (1952) Modification of Bayes Priors for...

View source: R/HodgesLehmann.R

HodgesLehmannR Documentation

Hodges-Lehmann (1952) Modification of Bayes Priors for Compound Decisions Given a prior G find a modified prior f that bounds minimax risk.

Description

There are two variants both minimize Fisher information for location via conic optimization:

\min \sum \frac{(f_{i+1}-f_i )^2}{( f_{i+1}+f_i )/2} = \sum \frac{u_i^2}{v_i/2} \approx I(F)

\Leftrightarrow \quad \min \sum w_i \; \mbox{s.t.} \; u_i^2 \leq 2 v_i w_i

Huber Variant as proposed in Efron and Morris (1971) imposing constraint

f(x) = \alpha \Phi * G + (1-\alpha) h(x)

Mallows Variant as proposed in Bickel (1983) imposing constraints

f(x) = \alpha \Phi * G + (1-\alpha) h(x), \; h(x) = \Phi * H

N.B. When the grid is not equispaced, one would have to include grid spacings.

Usage

HodgesLehmann(grid, G, alpha, type = "Huber", sd = 1, ...)

Arguments

grid

grid on which to interpolate Hodges-Lehmann solution

G

initial prior (should integrate to 1)

alpha

contamination proportion

type

either "Huber" or "Mallows"

sd

standard deviation of the Gaussian noise

...

other arguments to be passed to Mosek.

Value

A list containing:

x: grid for domain of marginal density

y: function values for modified marginal density at x

h: function values for contamination portion at x

d: Bayes rule for modified prior at x

H: function values for contamination prior distribution, only for the "Mallows" option

Author(s)

R. Koenker and J. Gu

References

Bickel, P. (1983), Minimax estimation of the mean of a normal distribution subject to doing well at a point, in M. H. Rizvi, J. S. Rustagi & D. Siegmund, eds, ‘Recent Advances in Statistics: Papers in Honor of Herman Chernoff on his Sixtieth Birthday’, Academic Press, pp. 511–528

Efron, B. & Morris, C. (1971), ‘Limiting the risk of Bayes and empirical Bayes estimators part I: the Bayes case’, Journal of the American Statistical Association 66, 807–815.

Hodges, J. L. & Lehmann, E. L. (1952), ‘The use of previous experience in reaching statistical decisions’, The Annals of Mathematical Statistics pp. 396–407.

Huber, P. (1964), ‘Robust estimation of a location parameter’, The Annals of Mathematical Statistics pp. 73–101.

Huber, P. (1974) "Fisher Information and Spline Interpolation." Ann. Statist. 2 (5) 1029 - 1033,

Mallows, C. (1978), ‘Problem 78-4, minimizing an integral’, SIAM Review 20, 183– 183.

See Also

HuberSpline


REBayes documentation built on March 1, 2026, 5:06 p.m.