Learn R Programming

REBayes (version 0.63)

Pmix: Poisson mixture estimation via Kiefer Wolfowitz MLE

Description

Poisson mixture estimation via Kiefer Wolfowitz MLE

Usage

Pmix(x, v = 300, exposure = NULL, ...)

Arguments

x
Data: Sample observations (integer valued)
v
Grid Values for the mixing distribution defaults to equal spacing of length v when v is specified as a scalar
exposure
observation specific exposures to risk see details
...
other parameters passed to KWDual to control optimization

Value

An object of class density with components:

Details

Kiefer Wolfowitz NPMLE estimation for Poisson mixtures.

In the default case exposure = 1 it is assumed that x contains individual observations that are aggregated into count bins via table. When exposure has the same length as codex then it is presumed to be individual specific risk exposure and the Poisson mixture is taken to be $x | v ~ Poi(v * exposure)$ and the is not aggregated. See for example the analysis of the Norberg data in Koenker and Gu (2016).

References

Kiefer, J. and J. Wolfowitz Consistency of the Maximum Likelihood Estimator in the Presence of Infinitely Many Incidental Parameters Ann. Math. Statist. Volume 27, Number 4 (1956), 887-906.

Koenker R. and J. Gu (2016) "REBayes: An R Package for Empirical Bayes Mixture Methods"