Learn R Programming

REBayes (version 0.63)

Rxiv: Archive function for auxiliary files for latex documents

Description

Creates a tar.gz file with all of the R files needed to recreate the tables and figures that appear in the paper. Should be considered experimental at this stage. It presumes that tables are generated with something like the Hmisc latex function and included in the latex document with input commands. Likewise figures are assumed to be included with includegraphics and generated by R in pdf format. This was originally developed to sort out the files for "Empirical Bayesball Remixed". An optional side of effect of the function to create a tar.gz file with the gzipped R files required for the paper.

Usage

Rxiv(fname, figures = "figures", tables = "tables", tar = FALSE)

Arguments

fname
name of the latex file of the paper sans .tex suffix
figures
name of the directory with the files for figures
tables
name of the directory with the files for tables
tar
logical flag, if TRUE generate a gzipped tar file of .R files

Value

a list with the following components a list with the following components