TLmix: NPMLE for Student t location mixtures
Description
Kiefer Wolfowitz NPMLE for Student t location mixtures
Usage
TLmix(x, v = 300, u = 300, df = 1, hist = FALSE, weights = NULL, ...)
Arguments
x
Data: Sample Observations
v
bin boundaries defaults to equal spacing of length v
u
bin boundaries for histogram binning: defaults to equal spacing
df
Number of degrees of freedom of Student base density
hist
If TRUE then aggregate x to histogram weights
weights
replicate weights for x obervations, should sum to 1
...
optional parameters passed to KWDual to control optimization
Value
An object of class density with components:
Details
Kiefer Wolfowitz MLE density estimation as proposed by Jiang and Zhang for
a Student t compound decision problem. The histogram option is intended
for large problems, say n > 1000, where reducing the sample size dimension
is desirable. By default the grid for the binning is equally spaced on the
support of the data. Equal spaced binning is problematic for Cauchy data.
References
Kiefer, J. and J. Wolfowitz Consistency of the Maximum
Likelihood Estimator in the Presence of Infinitely Many Incidental
Parameters Ann. Math. Statist. 27, (1956), 887-906.Jiang, Wenhua and Cun-Hui Zhang General maximum likelihood empirical Bayes
estimation of normal means Ann. Statist., 37, (2009), 1647-1684.
See Also
GLmix for Gaussian version