Learn R Programming

REBayes (version 0.63)

Tncpmix: NPMLE for Student t non-centrality parameter mixtures

Description

Kiefer Wolfowitz NPMLE for Student t non-centrality parameter mixtures Model: $y_{ig} = mu_{g} + e_{ig}, e_{ig} ~ N(0,sigma_{g}^{2})$ x is the vector of t statistics for all groups, which follows t dist if $mu_g = 0$, and noncentral t dist if $mu_g \neq 0$, with $ncp_{g} = \mu_g / \sigma_{g}$. This leads to a mixture of t distribution with ncp as the mixing parameter. df (degree of freedom) is determined by the group size in the simplest case.

Usage

Tncpmix(x, v = 300, u = 300, df = 1, hist = FALSE, weights = NULL, ...)

Arguments

x
Data: Sample Observations
v
bin boundaries defaults to equal spacing of length v
u
bin boundaries for histogram binning: defaults to equal spacing
df
Number of degrees of freedom of Student base density
hist
If TRUE then aggregate x to histogram weights
weights
replicate weights for x obervations, should sum to 1
...
optional parameters passed to KWDual to control optimization

Value

An object of class density with components:

References

Kiefer, J. and J. Wolfowitz Consistency of the Maximum Likelihood Estimator in the Presence of Infinitely Many Incidental Parameters Ann. Math. Statist. 27, (1956), 887-906.

See Also

GLmix for Gaussian version