Learn R Programming

REBayes (version 0.63)

WGVmix: WGVmix: Weighted Generalized Maximum Likelihood for Empirical Bayes Estimation of Gamma Variances

Description

A Kiefer-Wolfowitz procedure for ML estimation of a Gaussian model with independent variance components with weighted longitudinal data.

Usage

WGVmix(y, id, w, v, pv = 300, eps = 1e-06, rtol = 1e-06, verb = 0, control = NULL)

Arguments

y
A vector of observations
id
A strata indicator vector of the same length
w
A vector of weights
v
A vector of bin boundaries for the variance effects
pv
The number of variance effect bins, if u is missing
eps
A tolerance for determining the support of the bins
rtol
A tolerance for determining duality gap convergence tolerance in Mosek
verb
A flag indicating how verbose the Mosek output should be
control
Mosek control list see KWDual documentation

Value

An object of class density consisting of the following components: components:

Details

See Gu and Koenker (2012?)

References

Gu Y. and R. Koenker (2012) Empirical Bayesball