Learn R Programming

REBayes (version 0.63)

Weibullmix: NPMLE for Weibull Mixtures

Description

Kiefer-Wolfowitz NPMLE for Weibull Mixtures of scale parameter

Usage

Weibullmix(x, v = 300, u = 300, alpha, lambda = 1, hist = FALSE, weights = NULL, ...)

Arguments

x
Survival times
v
Grid values for mixing distribution
u
Grid values for histogram bins, if needed
alpha
Shape parameter for Weibull distribution
lambda
Scale parameter for Weibull Distribution; must either have length 1, or length equal to length(x) the latter case accommodates the possibility of a linear predictor
hist
If TRUE aggregate to histogram counts
weights
replicate weights for x obervations, should sum to 1
...
optional parameters passed to KWDual to control optimization

Value

An object of class density with components

Details

Kiefer Wolfowitz NPMLE density estimation for Weibull scale mixtures. The histogram option is intended for relatively large problems, say n > 1000, where reducing the sample size dimension is desirable. By default the grid for the binning is equally spaced on the support of the data. Parameterization: f(t|alpha, lambda) = alpha * exp(v) * (lambda * t )^(alpha-1) * exp(-(lambda * t)^alpha * exp(v)); shape = alpha; scale = lambda^(-1) * (exp(v))^(-1/alpha)

References

Kiefer, J. and J. Wolfowitz Consistency of the Maximum Likelihood Estimator in the Presence of Infinitely Many Incidental Parameters Ann. Math. Statist. Volume 27, Number 4 (1956), 887-906.

See Also

Gompertzmix