A Kiefer-Wolfowitz MLE for Gaussian models with independent variances. This
can be viewed as a general form for $\chi^2$ mixtures, see Gammamix
for a more general form for Gamma mixtures.
Usage
GVmix(x, m, v = 300, weights = NULL, ...)
Arguments
x
vector of observed variances
m
vector of sample sizes corresponding to x
v
A vector of bin boundaries, if scalar then v equally spaced bins
are constructed
weights
replicate weights for x obervations, should sum to 1
...
optional parameters passed to KWDual to control optimization
Value
An object of class density with components:
References
Koenker, R and I. Mizera, (2013) ``Convex Optimization, Shape Constraints,
Compound Decisions, and Empirical Bayes Rules,'' JASA, 109, 674--685.
Gu J. and R. Koenker (2014) Unobserved heterogeneity in
income dynamics: an empirical Bayes perspective, JBES, forthcoming.
See Also
Gammamix for a general implementation for Gamma mixtures