Pmix(x, v = 300, exposure = NULL, ...) In the default case exposure = 1 it is assumed that
x contains individual observations that are aggregated into
count bins via table. When exposure has the same length as
codex then it is presumed to be individual specific risk exposure and
the Poisson mixture is taken to be $x | v ~ Poi(v * exposure)$ and the
is not aggregated. See for example the analysis of the Norberg data in
Koenker and Gu (2016).
Koenker R. and J. Gu (2016) "REBayes: An R Package for Empirical Bayes Mixture Methods"