latex function and included in the latex document with
input commands. Likewise figures are assumed to be included with
includegraphics and generated by R in pdf format. This
was originally developed to sort out the files for "Empirical Bayesball Remixed".
An optional side of effect of the function to create a tar.gz file with the gzipped
R files required for the paper.
Rxiv(fname, figures = "figures", tables = "tables", tar = FALSE)