WGLVmix: Weighted NPMLE ofLongitudinal Gaussian Mean and Variances Model
Description
A Kiefer-Wolfowitz procedure for ML estimation of a Gaussian model with
dependent mean and variance components and weighted longitudinal data.
This version assumes a general bivariate distribution for the mixing
distribution. The defaults use a rather coarse bivariate gridding.
Usage
WGLVmix(y, id, w, u = 30, v = 30, ...)
Arguments
y
A vector of observations
id
A strata indicator vector of the same length
u
A vector of bin boundaries for the mean effects
v
A vector of bin boundaries for the variance effects
...
optional parameters to be passed to KWDual to control optimization
Value
A list consisting of the following components:
References
Gu, J. and R. Koenker (2014) Heterogeneous Income Dynamics: An
Empirical Bayes Perspective, JBES, forthcoming.
See Also
WTLVmix for an implementation assuming independent heterogeneity