WLVmix: NPMLE for Longitudinal Gaussian Means and Variances Model with Independent Prior
Description
A Kiefer-Wolfowitz NPMLE procedure for estimation of a Gaussian model with
independent mean and variance prior components with weighted longitudinal data.
This version iterates back and forth from Gamma and Gaussian forms of the likelihood.
Usage
WLVmix(y, id, w, u = 300, v = 300, eps = 1e-04, maxit = 2, ...)
Arguments
y
A vector of observations
id
A strata indicator vector indicating grouping of y
w
A vector of weights corresponding to y
u
A vector of bin boundaries for the mean effects
v
A vector of bin boundaries for the variance effects
eps
Convergence tolerance for iterations
maxit
A limit on the number of allowed iterations
...
optional parameters to be passed to KWDual to control optimization
Value
A list consisting of the following components:
References
Gu, J. and R. Koenker (2015) Empirical Bayesball Remixed, preprint
See Also
WGLVmix for a more general bivariate mixing distribution version and
WTLVmix for an alternative estimator exploiting a Student/Gamma decomposition