WTLVmix: NPMLE for Longitudinal Gaussian Means and Variances Model
Description
A Kiefer-Wolfowitz NPMLE procedure for estimation of a Gaussian model with
independent mean and variance components with weighted longitudinal data.
This version exploits a Student t decomposition of the likelihood.
Usage
WTLVmix(y, id, w, u = 300, v = 300, ...)
Arguments
y
A vector of observations
id
A strata indicator vector indicating grouping of y
w
A vector of weights corresponding to y
u
A vector of bin boundaries for the mean effects
v
A vector of bin boundaries for the variance effects
...
optional parameters to be passed to KWDual to control optimization
Value
A list consisting of the following components:
References
Gu, J. and R. Koenker (2015) Empirical Bayesball Remixed, preprint
See Also
WGLVmix for a more general bivariate mixing distribution version