Arguments
v
Grid values for mixing distribution
u
Grid values for histogram bins, if needed
alpha
Shape parameter for Weibull distribution
lambda
Scale parameter for Weibull Distribution; must either have length 1, or length
equal to length(x) the latter case accommodates the possibility of a linear predictor
hist
If TRUE aggregate to histogram counts
weights
replicate weights for x obervations, should sum to 1
...
optional parameters passed to KWDual to control optimization